package internal

import (
	"io"
	"os"
	"path/filepath"
)

func UpdateRelease(activeRelease, releaseFolder string) error {
	if err := os.RemoveAll(activeRelease); err != nil {
		return err
	}
	if err := os.MkdirAll(activeRelease, 0755); err != nil {
		return err
	}

	return CopyFolder(releaseFolder, activeRelease, true)
}

func CopyFolder(src, dst string, init bool) error {
	items, err := os.ReadDir(src)
	if err != nil {
		return err
	}

	for _, i := range items {
		info, err := i.Info()
		if err != nil {
			return err
		}

		src := filepath.Join(src, i.Name())
		dst := filepath.Join(dst, i.Name())
		if i.IsDir() {
			if err := os.MkdirAll(dst, info.Mode()); err != nil {
				return err
			}

			CopyFolder(src, dst, false)
			continue
		}

		f, err := os.Open(src)
		if err != nil {
			return err
		}

		dstFile, err := os.OpenFile(dst, os.O_WRONLY|os.O_CREATE, info.Mode())
		if err != nil {
			f.Close()
			return err
		}

		if _, err := io.Copy(dstFile, f); err != nil {
			f.Close()
			dstFile.Close()
			return err
		}

		f.Close()
		dstFile.Close()
	}

	return nil
}
